/**
 * Basic ASCII character indicators and character codes.
 * @module char-info/ascii
 * @preferred
 */
/**
 * Common ASCII character codes.
 */
export declare namespace AsciiCodes {
    const a: number;
    const f: number;
    const F: number;
    const z: number;
    const A: number;
    const Z: number;
    const zero: number;
    const nine: number;
    const newline: number;
    const maxAscii = 127;
    const carriageReturn: number;
    const space: number;
    const tab: number;
    const minus: number;
    const plus: number;
    const decimalPoint: number;
    const e: number;
    const E: number;
    const underscore: number;
}
/**
 * Returns true if `code` is a hex character: `[0-9a-fA-F]`.
 * @param code The character code.
 */
export declare function isHexCode(code: number): boolean;
/**
 * Returns true if `code` is a digit in base `base`.
 * @param code The character code.
 * @param base The base.
 */
export declare function isDigitCode(code: number, base?: number): boolean;
/**
 * Returns true if `code` is a latin letter, `[a-zA-Z]`.
 * @param code The character code.
 */
export declare function isLetterCode(code: number): boolean;
/**
 * Returns true if `code` is a latin uppercase letter, `[A-Z]`.
 * @param code The character code.
 */
export declare function isUpperCode(code: number): boolean;
/**
 * Returns true if `code` is a latin lowercase letter, `[a-z]`.
 * @param code The character code.
 */
export declare function isLowerCode(code: number): boolean;
/**
 * Returns true if `code` is an ASCII newline character: `[\r\n]`.
 * @param code The character code.
 */
export declare function isNewlineCode(code: number): boolean;
/**
 * Returns true if `code` is an ASCII inline space char: `[ \t]`.
 * @param code The character code.
 */
export declare function isSpaceCode(code: number): boolean;
/**
 * Returns true if `code` is a word character, which is a digit, a letter,
 * dash or underscore: `[0-9a-zA-Z_-]`.
 * @param code The character code.
 */
export declare function isWordCharCode(code: number): boolean;
/**
 * Returns true if `code` is an ASCII character code.
 * @param code The character code. The char code.
 */
export declare function isAsciiCode(code: number): boolean;
/**
 * Returns true if `char` begins with a hex character: `[a-fA-F0-9]`.
 * @param char A string representing a character.
 */
export declare function isHex(char: string): boolean;
/**
 * Returns true if `char` is a digit in base `base`.
 * @param char A string representing a character.
 * @param base The base.
 */
export declare function isDigit(char: string, base?: number): boolean;
/**
 * Returns true if `char` begins with a latin letter: `[A-Za-z]`.
 * @param char A string representing a character.
 */
export declare function isLetter(char: string): boolean;
/**
 * Returns true if `char` begins with an uppercase latin letter: `[A-Z]`.
 * @param char A string representing a character.
 */
export declare function isUpper(char: string): boolean;
/**
 * Returns true if `char` begins with a lowercase latin letter: `[a-z]`.
 * @param char A string representing a character.
 */
export declare function isLower(char: string): boolean;
/**
 * Returns true if `char` begins with a newline: `[\r\n]`.
 * @param char A string representing a character.
 */
export declare function isNewline(char: string): boolean;
/**
 * Returns true if `char` begins with an inline space: `[ \t]`.
 * @param char A string representing a character.
 */
export declare function isSpace(char: string): boolean;
/**
 * Returns true if `char` begins with a word char: a letter, digit, underscore,
 * or dash: `[a-zA-Z0-9_-].
 * @param char A string representing a character.
 */
export declare function isWordChar(char: string): boolean;
/**
 * Returns true if `char` begins with an ASCII character.
 * @param char A string representing a character.
 */
export declare function isAscii(char: string): boolean;
