/**
 * Unicode character indicators.
 *
 * @module char-info/unicode
 * @preferred
 */ /** */
import { BasicCharClassIndicator } from "./internal/indicators";
import { CharClassIndicator } from "./internal/indicator-type";
/**
 * Returns an indicator for characters belonging to the Unicode category,
 * `category`.
 * @param category The category to test for.
 */
export declare function uniInCategory(category: string): CharClassIndicator;
/**
 * Returns an indicator for characters belonging to a Unicode script, `script`.
 * @param script
 */
export declare function uniInScript(script: string): BasicCharClassIndicator;
/**
 * Returns an indicator for characters belonging to the Unicode block, `block`.
 * @param block
 */
export declare function uniInBlock(block: string): BasicCharClassIndicator;
/**
 * Indicator for Unicode decimal digit characters.
 */
export declare const uniIsDecimal: CharClassIndicator;
/**
 * Indicator for Unicode letters.
 */
export declare const uniIsLetter: CharClassIndicator;
/**
 * Indicator for Unicode lowercase letters.
 */
export declare const uniIsLower: CharClassIndicator;
/**
 * Indicator for Unicode uppercase letters.
 */
export declare const uniIsUpper: CharClassIndicator;
/**
 * Indicator for Unicode inline spaces.
 */
export declare const uniIsSpace: CharClassIndicator;
/**
 * Indicator for Unicode vertical separators.
 */
export declare const uniIsNewline: CharClassIndicator;
/**
 * Returns the Unicode categories for a character or code.
 */
export declare const uniGetCategories: {
    code(code: number): import("./internal/unicode-lookup").UnicodeCharGroup[];
    char(char: string): import("./internal/unicode-lookup").UnicodeCharGroup[];
};
/**
 * Returns the Unicode scripts for a character or code.
 */
export declare const uniGetScripts: {
    code(code: number): import("./internal/unicode-lookup").UnicodeCharGroup[];
    char(char: string): import("./internal/unicode-lookup").UnicodeCharGroup[];
};
/**
 * Returns the Unicode block for a character or code.
 */
export declare const uniGetBlock: {
    code(code: number): import("./internal/unicode-lookup").UnicodeCharGroup;
    char(char: string): import("./internal/unicode-lookup").UnicodeCharGroup;
};
export { UnicodeScript, UnicodeCategory, UnicodeBlock } from "./internal/names";
